Welcome to Cartouche — Cartouche 1.1 documentation

### Navigation

- index
- next |
- Cartouche 1.1 documentation »

# Welcome to Cartouche

Cartouche is a Sphinx extension for transforming easy-to-read docstrings into the reStructuredText consumed by Sphinx.

Contents:

- Installing `cartouche`
- Overview
- Functions and Methods
  - A typical docstring
  - Args
  - Return and Returns
  - Yield and Yields
  - Raises
- Classes and Attributes
- `cartouche` API
- Frequently Asked Questions
  - Where does the name `cartouche` come from?
  - Didn’t this project used to be called `hieroglyph`?
- Version 1.1
- Version 1.0
- Version 0.9

# Indices and tables

- Index
- Module Index
- Search Page

### Navigation

- index
- next |
- Cartouche 1.1 documentation »